
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.043.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Const::Fast" => 0,
    "Data::Dump" => 0,
    "Getopt::Long::Descriptive" => 0,
    "Module::Build" => "0.28",
    "Path::Tiny" => 0,
    "Text::Template" => 0
  },
  "dist_abstract" => "Generate html/javascript charts from perl data using javascript library plotly.js",
  "dist_author" => [
    "Pablo Rodr\x{ed}guez Gonz\x{e1}lez <pablo.rodriguez.gonzalez\@gmail.com>"
  ],
  "dist_name" => "Chart-Plotly",
  "dist_version" => "0.003",
  "license" => "mit",
  "module_name" => "Chart::Plotly",
  "recursive_test_files" => 1,
  "requires" => {
    "Exporter" => 0,
    "HTML::Show" => 0,
    "JSON" => 0,
    "Module::Load" => 0,
    "Moose" => 0,
    "Params::Validate" => 0,
    "Text::Template" => 0,
    "overload" => 0,
    "strict" => 0,
    "utf8" => 0,
    "vars" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "Test::More" => 0,
    "Test::Most" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "Test::Most" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
